build_graph

Function build_graph 

pub fn build_graph(root: &Utf8Path) -> ModuleGraph
Build the graph for a project root once, to be shared across engines. Honors .mollifyrc.json’s exclude_dirs in addition to the builtin discovery denylist (VCS metadata, virtualenvs, build/cache output).